@@ -1,6 +1,7 @@
 from enum import Enum
 from typing import Optional, Dict, List, Tuple
 
+from pydantic import UUID4
 from pydantic.main import BaseModel
 
 TextureMeta = Optional[Dict[str, str]]
@@ -21,7 +22,7 @@ class TextureItem(BaseModel):
 
 
 class TextureRequest(BaseModel):
-    uuid: str
+    uuid: UUID4
     texture_types: List[TextureType] = [TextureType.SKIN]
 
     class Config:
@@ -29,7 +30,7 @@ class TextureRequest(BaseModel):
 
 
 class TextureUploadRequest(BaseModel):
-    uuid: str
+    uuid: UUID4
     data: str
     kind: TextureType
     metadata: TextureMeta
